==> stackwriter-api-0.0.2-sources.jar: net/sozal/stackwriter/api/StackWriter.java <==
package net.sozal.stackwriter.api;

import net.sozal.stackwriter.api.domain.Frame;
import net.sozal.stackwriter.api.internal.StackWriterService;

/**
 * @author serkan
 */
public final class StackWriter {

    private static StackWriterService stackWriterService = new NoOpStackWriterService();

    private StackWriter() {
    }

    public static StackWriterService getStackWriterService() {
        return stackWriterService;
    }

    public static void setStackWriterService(StackWriterService stackWriterService) {
        StackWriter.stackWriterService = stackWriterService;
    }

    public static Frame[] takeSnapshot() {
        return stackWriterService.takeSnapshot();
    }

    public static Frame[] takeSnapshot(int startDepth, int maxFrameCount) {
        return stackWriterService.takeSnapshot(startDepth, maxFrameCount);
    }

    public static Frame[] takeSnapshotWithStartDepth(int startDepth) {
        return stackWriterService.takeSnapshotWithStartDepth(startDepth);
    }

    public static Frame[] takeSnapshotWithMaxFrameCount(int maxFrameCount) {
        return stackWriterService.takeSnapshotWithMaxFrameCount(maxFrameCount);
    }

    public static void addAppPackage(String newAppPackage) {
        stackWriterService.addAppPackage(newAppPackage);
    }

    public static void useErrorListener(ErrorListener errorListener) {
        stackWriterService.useErrorListener(errorListener);
    }

    private static class NoOpStackWriterService implements StackWriterService {

        private static final Frame[] EMPTY_FRAME = new Frame[0];

        @Override
        public Frame[] takeSnapshot() {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshot(int startDepth, int maxFrameCount) {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshotWithStartDepth(int startDepth) {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshotWithMaxFrameCount(int maxFrameCount) {
            return EMPTY_FRAME;
        }

        @Override
        public void addAppPackage(String appPackage) {
        }

        @Override
        public void useErrorListener(ErrorListener errorListener) {
        }

    }

}

==> stackwriter-api-0.0.5-sources.jar: net/sozal/stackwriter/api/StackWriter.java <==
package net.sozal.stackwriter.api;

import net.sozal.stackwriter.api.domain.Frame;
import net.sozal.stackwriter.api.internal.StackWriterService;

/**
 * @author serkan
 */
public final class StackWriter {

    private static StackWriterService stackWriterService = new NoOpStackWriterService();

    private StackWriter() {
    }

    public static StackWriterService getStackWriterService() {
        return stackWriterService;
    }

    public static void setStackWriterService(StackWriterService stackWriterService) {
        StackWriter.stackWriterService = stackWriterService;
    }

    public static Frame[] takeSnapshot() {
        return stackWriterService.takeSnapshot();
    }

    public static Frame[] takeSnapshot(int startDepth, int maxFrameCount) {
        return stackWriterService.takeSnapshot(startDepth, maxFrameCount);
    }

    public static Frame[] takeSnapshotWithStartDepth(int startDepth) {
        return stackWriterService.takeSnapshotWithStartDepth(startDepth);
    }

    public static Frame[] takeSnapshotWithMaxFrameCount(int maxFrameCount) {
        return stackWriterService.takeSnapshotWithMaxFrameCount(maxFrameCount);
    }

    public static void addAppPackage(String newAppPackage) {
        stackWriterService.addAppPackage(newAppPackage);
    }

    public static void addIgnoredExceptionType(Class<? extends Throwable> exceptionType) {
        stackWriterService.addIgnoredExceptionType(exceptionType);
    }

    public static void useErrorListener(ErrorListener errorListener) {
        stackWriterService.useErrorListener(errorListener);
    }

    private static class NoOpStackWriterService implements StackWriterService {

        private static final Frame[] EMPTY_FRAME = new Frame[0];

        @Override
        public Frame[] takeSnapshot() {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshot(int startDepth, int maxFrameCount) {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshotWithStartDepth(int startDepth) {
            return EMPTY_FRAME;
        }

        @Override
        public Frame[] takeSnapshotWithMaxFrameCount(int maxFrameCount) {
            return EMPTY_FRAME;
        }

        @Override
        public void addAppPackage(String appPackage) {
        }

        @Override
        public void addIgnoredExceptionType(Class<? extends Throwable> exceptionType) {
        }

        @Override
        public void useErrorListener(ErrorListener errorListener) {
        }

    }

}
